@@ -47,11 +47,7 @@ describe 'ironic::client' do
       let(:platform_params) do
         case facts[:osfamily]
         when 'Debian'
-          if facts[:os_package_type] == 'debian'
-            { :client_package_name => 'python3-ironicclient' }
-          else
-            { :client_package_name => 'python-ironicclient' }
-          end
+          { :client_package_name => 'python3-ironicclient' }
         when 'RedHat'
           { :client_package_name => 'python-ironicclient' }
         end
