@@ -24,7 +24,6 @@ describe 'ironic' do
 
   let :params do
     { :package_ensure              => 'present',
-      :debug                       => false,
       :database_connection         => 'sqlite:////var/lib/ironic/ironic.sqlite',
       :database_max_retries        => 10,
       :database_idle_timeout       => 3600,
@@ -36,38 +35,33 @@ describe 'ironic' do
 
   shared_examples_for 'ironic' do
 
-    context 'and if rabbit_host parameter is provided' do
+    context 'ironic setup' do
       it_configures 'a ironic base installation'
       it_configures 'with SSL disabled'
       it_configures 'with SSL enabled without kombu'
       it_configures 'with SSL enabled with kombu'
       it_configures 'with amqp_durable_queues disabled'
       it_configures 'with amqp_durable_queues enabled'
+      it_configures 'without rabbit HA'
     end
 
-    context 'and if rabbit_hosts parameter is provided' do
-
-      context 'with one server' do
-        it_configures 'a ironic base installation'
-        it_configures 'rabbit HA with a single virtual host'
-      end
-
-      context 'with multiple servers' do
-        before { params.merge!( :rabbit_ha_queues => true ) }
-        it_configures 'a ironic base installation'
-        it_configures 'rabbit HA with multiple hosts'
-      end
+    context 'ironic setup with rabbit HA' do
+      before { params.merge!( :rabbit_ha_queues => true ) }
+      it_configures 'with rabbit HA'
     end
 
     context 'with amqp messaging' do
       it_configures 'amqp support'
     end
 
+    context 'with oslo messaging notifications' do
+      it_configures 'oslo messaging notifications'
+    end
+
   end
 
   shared_examples_for 'a ironic base installation' do
 
-    it { is_expected.to contain_class('ironic::logging') }
     it { is_expected.to contain_class('ironic::params') }
 
     it { is_expected.to contain_class('ironic::glance') }
@@ -109,20 +103,23 @@ describe 'ironic' do
     it 'configures ironic.conf' do
       is_expected.to contain_ironic_config('DEFAULT/auth_strategy').with_value('keystone')
       is_expected.to contain_ironic_config('DEFAULT/my_ip').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_ironic_config('DEFAULT/executor_thread_pool_size').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('DEFAULT/rpc_response_timeout').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('DEFAULT/control_exchange').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('DEFAULT/transport_url').with_value('<SERVICE DEFAULT>').with_secret(true)
       is_expected.to contain_ironic_config('DEFAULT/default_resource_class').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_ironic_config('DEFAULT/notification_level').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_ironic_config('DEFAULT/versioned_notifications_topics').with_value('<SERVICE DEFAULT>')
     end
   end
 
-  shared_examples_for 'rabbit HA with a single virtual host' do
+  shared_examples_for 'without rabbit HA' do
     it 'in ironic.conf' do
       is_expected.to contain_ironic_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('<SERVICE DEFAULT>')
     end
   end
 
-  shared_examples_for 'rabbit HA with multiple hosts' do
+  shared_examples_for 'with rabbit HA' do
     it 'in ironic.conf' do
       is_expected.to contain_ironic_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value(true)
     end
@@ -185,6 +182,25 @@ describe 'ironic' do
     it { is_expected.to contain_ironic_config('oslo_messaging_rabbit/amqp_durable_queues').with_value(true) }
   end
 
+  shared_examples_for 'oslo messaging notifications' do
+    context 'with default parameters' do
+      it { is_expected.to contain_ironic_config('oslo_messaging_notifications/transport_url').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_ironic_config('oslo_messaging_notifications/driver').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_ironic_config('oslo_messaging_notifications/topics').with_value('<SERVICE DEFAULT>') }
+    end
+
+    context 'with overridden notification parameters' do
+      before { params.merge!(
+        :notification_driver        => 'messagingv2',
+        :notification_transport_url => 'http://host:port',
+      ) }
+
+      it { is_expected.to contain_ironic_config('oslo_messaging_notifications/transport_url').with_value('http://host:port') }
+      it { is_expected.to contain_ironic_config('oslo_messaging_notifications/driver').with_value('messagingv2') }
+      it { is_expected.to contain_ironic_config('oslo_messaging_notifications/topics').with_value('<SERVICE DEFAULT>') }
+    end
+  end
+
   shared_examples_for 'amqp support' do
     context 'with default parameters' do
       it { is_expected.to contain_ironic_config('oslo_messaging_amqp/server_request_prefix').with_value('<SERVICE DEFAULT>') }
@@ -248,13 +264,8 @@ describe 'ironic' do
       let :platform_params do
         case facts[:osfamily]
         when 'Debian'
-          if facts[:os_package_type] == 'debian' then
-            ironic_lib_pkgname = 'python3-ironic-lib'
-          else
-            ironic_lib_pkgname = 'python-ironic-lib'
-          end
           { :common_package_name => 'ironic-common',
-            :lib_package_name    => ironic_lib_pkgname }
+            :lib_package_name    => 'python3-ironic-lib' }
         when 'RedHat'
           { :common_package_name => 'openstack-ironic-common',
             :lib_package_name    => 'python-ironic-lib' }
