@@ -38,23 +38,27 @@ describe 'ironic::inspector' do
       :ironic_auth_type      => 'password',
       :ironic_username       => 'ironic',
       :ironic_tenant_name    => 'services',
-      :ironic_auth_url       => 'http://127.0.0.1:5000/v2.0',
+      :ironic_auth_url       => 'http://127.0.0.1:5000/v3',
       :ironic_max_retries    => 30,
       :ironic_retry_interval => 2,
       :swift_auth_type       => 'password',
       :swift_username        => 'ironic',
       :swift_tenant_name     => 'services',
-      :swift_auth_url        => 'http://127.0.0.1:5000/v2.0',
+      :swift_auth_url        => 'http://127.0.0.1:5000/v3',
       :dnsmasq_ip_subnets    => [{ 'ip_range' =>
                                       '192.168.0.100,192.168.0.120' },
                                  { 'tag'      => 'subnet1',
                                    'ip_range' => '192.168.1.100,192.168.1.200',
                                    'netmask'  => '255.255.255.0',
                                    'gateway'  => '192.168.1.254' },
-                                 { 'tag'      => 'subnet2',
-                                   'ip_range' => '192.168.2.100,192.168.2.200',
-                                   'netmask'  => '255.255.255.0',
-                                   'gateway'  => '192.168.2.254' }],
+                                 { 'tag'                     => 'subnet2',
+                                   'ip_range'                => '192.168.2.100,192.168.2.200',
+                                   'netmask'                 => '255.255.255.0',
+                                   'gateway'                 => '192.168.2.254',
+                                   'classless_static_routes' => [{'destination' => '1.2.3.0/24',
+                                                                  'nexthop'     => '192.168.2.1'},
+                                                                 {'destination' => '4.5.6.0/24',
+                                                                  'nexthop'     => '192.168.2.1'}]}],
       :dnsmasq_local_ip      => '192.168.0.1',
       :ipxe_timeout          => 0,
       :http_port             => 8088,
@@ -70,7 +74,6 @@ describe 'ironic::inspector' do
     end
 
     it { is_expected.to contain_class('ironic::params') }
-    it { is_expected.to contain_class('ironic::inspector::logging') }
 
     it 'installs ironic inspector package' do
       if platform_params.has_key?(:inspector_package)
@@ -102,6 +105,7 @@ describe 'ironic::inspector' do
       is_expected.to contain_ironic_inspector_config('DEFAULT/listen_address').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ironic_inspector_config('DEFAULT/auth_strategy').with_value(p[:auth_strategy])
       is_expected.to contain_ironic_inspector_config('DEFAULT/timeout').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_ironic_inspector_config('DEFAULT/transport_url').with_value('fake://')
       is_expected.to contain_ironic_inspector_config('capabilities/boot_mode').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ironic_inspector_config('iptables/dnsmasq_interface').with_value(p[:dnsmasq_interface])
       is_expected.to contain_ironic_inspector_config('processing/ramdisk_logs_dir').with_value(p[:ramdisk_logs_dir])
@@ -157,6 +161,9 @@ describe 'ironic::inspector' do
       is_expected.to contain_file('/etc/ironic-inspector/dnsmasq.conf').with_content(
         /dhcp-option=tag:subnet2,option:router,192.168.2.254/
       )
+      is_expected.to contain_file('/etc/ironic-inspector/dnsmasq.conf').with_content(
+        /dhcp-option=tag:subnet2,option:classless-static-route,1.2.3.0\/24,192.168.2.1,4.5.6.0\/24,192.168.2.1/
+      )
     end
     it 'should contain file /tftpboot/pxelinux.cfg/default' do
       is_expected.to contain_file('/tftpboot/pxelinux.cfg/default').with(
@@ -175,16 +182,16 @@ describe 'ironic::inspector' do
     context 'when overriding parameters' do
       before :each do
         params.merge!(
-          :debug                       => true,
+          :dhcp_debug                  => true,
           :listen_address              => '127.0.0.1',
           :ironic_password             => 'password',
           :ironic_project_domain_name  => 'Default',
           :ironic_user_domain_name     => 'Default',
-          :ironic_auth_url             => 'http://192.168.0.1:5000/v2.0',
+          :ironic_auth_url             => 'http://192.168.0.1:5000/v3',
           :swift_password              => 'password',
           :swift_project_domain_name   => 'Default',
           :swift_user_domain_name      => 'Default',
-          :swift_auth_url              => 'http://192.168.0.1:5000/v2.0',
+          :swift_auth_url              => 'http://192.168.0.1:5000/v3',
           :pxe_transfer_protocol       => 'http',
           :additional_processing_hooks => 'hook1,hook2',
           :ramdisk_kernel_args         => 'foo=bar',
@@ -194,15 +201,13 @@ describe 'ironic::inspector' do
           :detect_boot_mode            => true,
           :node_not_found_hook         => 'enroll',
           :discovery_default_driver    => 'pxe_ipmitool',
-          :dnsmasq_ip_subnets          => [],
-          :dnsmasq_ip_range            => '192.168.0.100,192.168.0.120',
+          :dnsmasq_ip_subnets          => [{'ip_range' => '192.168.0.100,192.168.0.120'}],
           :add_ports                   => 'all',
           :always_store_ramdisk_logs   => true,
         )
       end
       it 'should replace default parameter with new value' do
         is_expected.to contain_ironic_inspector_config('DEFAULT/listen_address').with_value(p[:listen_address])
-        is_expected.to contain_ironic_inspector_config('DEFAULT/debug').with_value(p[:debug])
         is_expected.to contain_ironic_inspector_config('capabilities/boot_mode').with_value(p[:detect_boot_mode])
         is_expected.to contain_ironic_inspector_config('ironic/password').with_value(p[:ironic_password]).with_secret(true)
         is_expected.to contain_ironic_inspector_config('ironic/project_domain_name').with_value(p[:ironic_project_domain_name])
@@ -265,6 +270,37 @@ describe 'ironic::inspector' do
         end
       end
     end
+
+    context 'when enabling ppc64le support' do
+      let :pre_condition do
+         "class { 'ironic::inspector::authtoken': password       => 'password', }
+          class { 'ironic::pxe':                  enable_ppc64le => true, }"
+      end
+
+      before do
+        params.merge!(
+          :enable_ppc64le => true,
+        )
+      end
+
+      it 'should contain file /etc/ironic-inspector/dnsmasq.conf' do
+          is_expected.to contain_file('/etc/ironic-inspector/dnsmasq.conf').with_content(
+            /dhcp-match=set:ppc64le,option:client-arch,14/)
+      end
+      it 'should contain file /tftpboot/ppc64le/default' do
+        is_expected.to contain_file('/tftpboot/ppc64le/default').with(
+          'owner'   => 'ironic-inspector',
+          'group'   => 'ironic-inspector',
+          'seltype' => 'tftpdir_t',
+          'ensure'  => 'present',
+          'require' => 'Anchor[ironic-inspector::config::begin]',
+          'content' => /default/,
+        )
+        is_expected.to contain_file('/tftpboot/ppc64le/default').with_content(
+            /initrd=agent.ramdisk ipa-inspection-callback-url=http:\/\/192.168.0.1:5050\/v1\/continue ipa-inspection-collectors=default/
+        )
+      end
+    end
   end
 
   on_supported_os({
